//4.1a) Set-up your do-file. 
capture log close
log using icpsrcda-04-ordinal, replace text

//  program:    icpsrcda-04-ordinal.do
//  task:       Review 4 - Ordinal Regression
//  project:    ICPSR CDA
//  author:     Trent Mize \ 2014-06-24
//	updated:	SNS		   \ 2017-07-16

*program setup
version 	14.0
clear 		all 
set 		linesize 80

//4.1b) Load the Data.
usecda 	cda_scireview3

//4.1c) Examine data, select variables, drop missing, and verify. 
codebook, 	compact
keep 		jobprst pub1 phd female
misschk, 	gen(m)
tab 		mnumber
keep if 	mnumber==0
codebook 	jobprst pub1 phd female, compact
sum 		jobprst pub1 phd female

//4.2) Produce table including distribution of output variable. 
tab1 		jobprst, mis

//4.3) Estimate the Ordered Logit. 
ologit 		jobprst pub1 phd i.female

//4.4-6) Odds Ratios. 
listcoef, 	help
listcoef, 	percent help

//4.7) Compute Discrete Change for C and B. 
mchange 	female pub1, atmeans

//4.8) Graph Predicted Probabilities. 
**Generate new variables to plot
mgen,		at(pub1=(0(1)20)) atmeans stub(pubpr)

label var pubprpr1 "Pr(Adeq)"
label var pubprpr2 "Pr(Good)"
label var pubprpr3 "Pr(Strg)"
label var pubprpr4 "Pr(Dist)"
label var pubprCpr1 "Pr(<=Adeq)"
label var pubprCpr2 "Pr(<=Good)"
label var pubprCpr3 "Pr(<=Strg)"
label var pubprCpr4 "Pr(<=Dist)"

**Graph predicted probabilities
graph twoway (connected pubprpr1 pubprpr2 pubprpr3 pubprpr4 pubprpub1, ///
		title("Job Prestige and Publications") ///
		subtitle("(Other Variables Held at Means)") ///
		ytitle("Predicted Pr(Job Prestige)") ///
		xtitle("Publications: PhD yr -1 to 1") ///
		xlabel(0(5)20) ylabel(0(.25)1, grid) ///
		msymbol(Oh Dh Sh Th))  
	
graph export icpsrcda04-ordinal-fig1.png , width(1200) replace
	
**Graph cumulative probabilities
graph twoway (connected pubprCpr1 pubprCpr2 pubprCpr3 pubprCpr4 pubprpub1, ///
		title("Job Prestige and Publications") ///
		subtitle("(Other Variables Held at Means)") ///
		ytitle("Cumulative Pr(Job Prestige)") ///
		xtitle("Publications: PhD yr -1 to 1") ///
		xlabel(0(5)20) ylabel(0(.25)1, grid) ///
		msymbol(Oh Dh Sh Th) name(tmp2, replace) ///
		text(.01 .75 "Adeq", place(e)) ///
		text(.22 5 "Good", place(e)) ///
		text(.60 10 "Strong", place(e)) ///
		text(.90 17 "Dist", place(e))), ///
		legend(off)  

graph export icpsrcda04-ordinal-fig2.png , width(1200) replace

// 4.14) Testing the Parallel Regression Assumption. 
brant, 	detail

//4.END) Close the Log File and Exit Do File. 
log close
exit





