//7.1) Set-up your do-file and load your data. 
capture log close       			  
log using 	icpsrcda-07-advanced, replace text   

//  program:    icpsrcda-07-advanced.do
//  task:       Advanced techniques
//  project:    ICPSR CDA
//  author:     Trent Mize \ 2014-06-24
//	updated:	SNS		   \ 2017-07-16

*program setup
version 	14.0
clear 		all 
set 		linesize 80        

// 7.1) Load Data
usecda 	cda_scireview3

// 7.2) Using locals. 
*Using locals to refer to a variable list
local ivs "fellow phd mcit3 mnas"
sum `ivs'

*Example setting up a logit model. 
logit 	faculty fellow phd mcit3 mnas
est 	store reg

local dv 	"faculty"
local ivs 	"fellow phd mcit3 mnas"
logit 		`dv' `iv'
est store local

esttab reg local

// 7.3) Setting up loops.

*Example: Recoding variables.
forvalues v = 2/5 {
	gen phdlt_`v' = phd<`v' if phd < .
	label var phdlt_`v' "PhD<`v'"
	}
	
codebook phdlt*, compact

*Example: Generating interaction terms.
foreach v in mcit3 phd fellow {
	gen femX`v'= female * `v'
	label var femX`v' "Female x `v'"
	}
codebook femX*, compact

// 7.4) Generating matrices.

*define locals
local var fellow faculty phdlt_2 phdlt_3 phdlt_4
local q quietly

*define matrix
local nvars: word count `var'
matrix outmat= J(`nvars',2,.)
matrix colnames outmat = femaleMN maleMN
matrix rownames outmat=`var'
local irow=0

*loop through variables
foreach v of varlist `var' {
	local ++irow
	`q' sum `v' if female==1
	local fem = r(mean)
	`q' sum `v' if female==0
	local male = r(mean)
* populate matrix
	mat outmat[`irow',1] = `fem'
	mat outmat[`irow',2] = `male'
	} //end v loop

*print matrix	
mat list outmat, f(%6.3f) ///
	title("Means for select variables, by gender")
	

*exit do-file
log close
exit



